# Tests instructions

### Creating a clean environment

From the root directory, run

    python -m venv ../venv-testppd
    source ../venv-testppd/bin/activate 
    pip install pypendentdrop[full]


### Running the tests

From the root directory, run

    python ./examplescript.py 
    python ./tests/testppd_1.py 
    python ./tests/testppd_2.py
    python ./tests/testppd_3.py 

    